/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package javax.management;

/**
 * An And Query Expression.<p>
 *
 * Returns true only when both expressions are true.
 *
 * <p><b>Revisions:</b>
 * <p><b>20020314 Adrian Brock:</b>
 * <ul>
 * <li>Fix the human readable expression
 * </ul>
 * <p><b>20020317 Adrian Brock:</b>
 * <ul>
 * <li>Make queries thread safe
 * </ul>
 * 
 * @author  <a href="mailto:Adrian.Brock@HappeningTimes.com">Adrian Brock</a>.
 * @version $Revision: 1.8.4.1 $
 */
class AndQueryExp extends QueryEval implements QueryExp
{
   // Constants ---------------------------------------------------

   private static final long serialVersionUID = -1081892073854801359L;
   
   // Attributes --------------------------------------------------

   /**
    * The first query expression
    */
   private QueryExp exp1;

   /**
    * The second query expression
    */
   private QueryExp exp2;

   // Static ------------------------------------------------------

   // Constructors ------------------------------------------------

   public AndQueryExp()
   {
   }
   
   /**
    * Create a new AND query Expression
    * 
    * @param first the first query expression
    * @param second the second query expression
    */
   public AndQueryExp(QueryExp first, QueryExp second)
   {
      this.exp1 = first;
      this.exp2 = second;
   }

   // Public ------------------------------------------------------

   // QueryExp implementation -------------------------------------

   public boolean apply(ObjectName name)
      throws BadStringOperationException,
      BadBinaryOpValueExpException,
      BadAttributeValueExpException,
      InvalidApplicationException
   {
      return exp1.apply(name) && exp2.apply(name); 
   }

   // Object overrides --------------------------------------------

   public String toString()
   {
      return new String("(" +exp1.toString() + ") && (" + exp2.toString()) + ")";
   }

   // Protected ---------------------------------------------------

   // Private -----------------------------------------------------

   // Inner classes -----------------------------------------------
}
