/*
* JBoss, the OpenSource J2EE webOS
*
* Distributable under LGPL license.
* See terms of license at gnu.org.
*/
package org.jboss.test.cluster.test;

import java.util.Properties;
import java.rmi.dgc.VMID;
import javax.naming.Context;
import javax.naming.InitialContext;

import junit.framework.Test;

import org.jboss.test.JBossClusteredTestCase;
import org.jboss.test.cluster.ejb.CalledHome;
import org.jboss.test.cluster.ejb.CalledRemote;

/**
 * Tests of inter-server ejb calls
 *
 * @author Scott.Stark@jboss.org
 * @version $Revision: 1.1 $
 */
public class CrossServerCallsUnitTestCase extends JBossClusteredTestCase
{
   public CrossServerCallsUnitTestCase (String name)
   {
      super(name);
   }

   public static Test suite() throws Exception
   {
      Test t1 = JBossClusteredTestCase.getDeploySetup(CrossServerCallsUnitTestCase.class, "cross-server.jar");
      return t1;
   }

   public void testEjb2EjbCall() 
      throws Exception
   {       
      log.info("+++ testEjb2EjbCall");

      // Connect to the server0 JNDI
      String[] urls = getNamingURLs();
      Properties env1 = new Properties();
      env1.setProperty(Context.INITIAL_CONTEXT_FACTORY,
         "org.jnp.interfaces.NamingContextFactory");
      env1.setProperty(Context.PROVIDER_URL, urls[0]);
      InitialContext ctx = new InitialContext(env1);
      
      CalledHome home = (CalledHome) ctx.lookup("cluster.ejb.CalledHome");
      CalledRemote bean = home.create();
      VMID[] ids = bean.invokeCall(urls[1], "cluster.ejb.CalleeHome");
      log.info("VMID[0] = "+ids[0]);
      log.info("VMID[1] = "+ids[1]);
      assertTrue("VMID[0] != VMID[1]", ids[0].equals(ids[1]) == false);
      bean.remove();
      log.info("done");
   }

}
